#
# spec file for package tpm2.0-abrmd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tpm2.0-abrmd
Version:        2.0.2
Release:        lp151.4.3.1
Summary:        Intel's TCG Software Stack Access Broker & Resource Manager for TPM 2.0 chips
License:        BSD-2-Clause
Group:          Productivity/Security
Url:            https://github.com/tpm2-software/tpm2-abrmd
Source0:        https://github.com/tpm2-software/tpm2-abrmd/releases/download/%{version}/tpm2-abrmd-%{version}.tar.gz
Source1:        tpm2.0-abrmd.rpmlintrc
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(tss2-sys)
Requires(pre):  pwdutils
Recommends:     libtss2-tcti-device0
Recommends:     libtss2-tcti-tabrmd0
Requires:       tpm2-0-tss
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# the auto activation is not whitelisted for <= SLE12-SP3
%if 0%{?sle_version} > 120300 || 0%{?is_opensuse}
%define install_dbus_files 1
%endif

%description
The tpm2.0-abrmd package provides the TPM2 Access Broker & Resource Manager.
This is a daemon service that coordinates requests to the TPM2 chip via
Intel's TPM 2.0 software stack.

%package devel
Summary:        Development headers the Access Broker & Resource Manager for TPM 2.0 chips
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libtss2-tcti-tabrmd0 = %{version}
Requires:       tpm2.0-abrmd = %{version}

%description devel
This package provides the development files for the Access Broker & Resource
Manager for coordinating access to TPM 2.0 chips.

%package -n libtss2-tcti-tabrmd0
Summary:        Client interface library for tpm2-abrmd
Group:          System/Libraries

%description -n libtss2-tcti-tabrmd0
This library allows to interact with the tpm2-abrmd daemon. It is intended for
use with the SAPI library (libtss2-sys) like any other TCTI.

%post -n libtss2-tcti-tabrmd0 -p /sbin/ldconfig
%postun -n libtss2-tcti-tabrmd0 -p /sbin/ldconfig

%prep
%setup -q -n tpm2-abrmd-%{version}

%build
export CFLAGS="%optflags -fPIE"
export LDFLAGS="-pie -fPIE"
# workaround for the bug that upstream commit
# b4036908dd067f8eadc9d53b1a2a39032aed109d fixes
export GDBUS_CODEGEN="/usr/bin/gdbus-codegen"
%configure --disable-static --with-systemdsystemunitdir=%{_unitdir}
make %{?_smp_mflags} PTHREAD_LDFLAGS=-pthread

# TODO: add the tss user again
%install
%make_install
# don't package libtool files as is best practice
find %{buildroot} -type f -name "*.la" -delete -print
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rctpm2-abrmd
# don't install the systemd preset, our presets are handled by
# systemd-presets-* packages
rm %{buildroot}/usr/lib*/systemd/system-preset/tpm2-abrmd.preset
%if ! 0%{?install_dbus_files}
rm %{buildroot}/%{_sysconfdir}/dbus-1/system.d/tpm2-abrmd.conf
rm %{buildroot}/%{_datadir}/dbus-1/system-services/com.intel.tss2.Tabrmd.service
%endif

%pre
%service_add_pre tpm2-abrmd.service

%post
%service_add_post tpm2-abrmd.service

%postun
%service_del_postun tpm2-abrmd.service

%preun
%service_del_preun tpm2-abrmd.service

%files
%defattr(-,root,root)
%doc *.md LICENSE
%{_mandir}/man7/tss2-*
%{_mandir}/man8/tpm2-*
%{_sbindir}/tpm2-abrmd
%{_sbindir}/rctpm2-abrmd
%{_unitdir}/tpm2-abrmd.service
%if 0%{?install_dbus_files}
# the auto activation is not whitelisted for <= SLE12-SP3
%config %{_sysconfdir}/dbus-1/system.d/tpm2-abrmd.conf
%{_datadir}/dbus-1/system-services/com.intel.tss2.Tabrmd.service
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/tss2
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/Tss2*

%files -n libtss2-tcti-tabrmd0
%defattr(-,root,root)
%{_libdir}/libtss2-tcti-tabrmd.so.*

%changelog
* Fri Dec 13 2019 mgerstner <matthias.gerstner@suse.com>
- fix_dlopen.patch: remove this patch to fix tcti loading using shorthand
  names like `--tcti=mssim`. Upstream already has an appropriate patch
  included in the packaged version that works for both shorthand and full
  version specificaton (bsc#1159176).
* Thu Oct 25 2018 matthias.gerstner@suse.com
- add a Requires towards tpm2-0-tss, because that main package holds the udev
  rules and logic for setting up the tss user. Without this the daemon can't
  start up correctly.
* Tue Oct 23 2018 matthias.gerstner@suse.com
- fix broken build due to newer glib dependency that reports a full path for
  gdbus-codegen, breaking the configure check.
* Wed Sep 26 2018 matthias.gerstner@suse.com
- update to version 2.0.2 (FATE#326270):
  - --enable-integration option to configure script now works as documented.
  - Format specifier with wrong size in util module.
  - Initialize TCTI context to 0 before setting values. This will cause all
    members that aren't explicitly initialized by be 0.
* Tue Sep 18 2018 matthias.gerstner@suse.com
- add recommends to the tcti-device and tcti-abrmd. Otherwise they're not
  installed right away, rendering the abrmd quite unusable.
* Fri Aug 10 2018 matthias.gerstner@suse.com
- Update to version 2.0.1:
  * SessionList: Fix Connection object reference leak.
  * source/sink: Organize ControlMessage processing.
  * CommandSource: Replace 'connection-removed' signal with ControlMessage.
  * SessionList: Remove all locking.
  * ConnectionManager: Remove 'connection-removed' signal.
  * ci: Build 'check' target when CC is gcc.
  * build: Fix bad URLs in configure script.
  * CHANGELOG.md: Add version number and date for 2.0.1 release.
  * Replace references to drand48_r family of functions for portability
  * Fix for type-punned pointer reported in newer compilers that enforce strict aliasing
* Tue Jul  3 2018 matthias.gerstner@suse.com
- Trying to fix build on older distros that fail because of a missing or
  broken autoconf valgrind detection macro. Removing  autoreconf to hopefully
  fix this.
* Mon Jul  2 2018 matthias.gerstner@suse.com
- add fix_dlopen.patch: fixes an issue with dlopen()'ing the tcti-device
  library from tpm2-0-tss. See
  https://github.com/tpm2-software/tpm2-abrmd/issues/486.
* Fri Jun 29 2018 matthias.gerstner@suse.com
- update to major version 2.0.0:
  - support_dbus_activation.diff: removed, is not contained upstream
  - the tpm2 stack introduces an incompatible ABI to the previous version with
    this update. There is no compatibility layer, libraries have new names
  etc.
  - upstream changelog:
    [#]# 2.0.0 - 2018-06-22
    [#]## Added
  - Integration test script and build support to execute integration tests
    against a physical TPM2 device on the build platform.
  - Implementation of dynamic TCTI initialization mechanism.
  - configure option `--enable-integration` to enable integration tests.
    The simulator executable must be on PATH.
  - Support for version 2.0 of tpm2-tss libraries.
    [#]## Changed
  - 'max-transient-objects' command line option renamted to 'max-transients'.
  - Added -Wextra for more strict checks at compile time.
  - Install location of headers to $(includedir)/tss2.
    [#]## Fixed
  - Added missing checks for NULL parameters identified by the check-build.
  - Bug in session continuation logic.
  - Off by one error in HandleMap.
  - Memory leak and uninitialized variable issues in unit tests.
    [#]## Removed
  - Command line option --fail-on-loaded-trans.
  - udev rules for TPM device node. This now lives in the tpm2-tss repo.
  - Remove legacy TCTI initialization functions.
  - configure option `--with-simulatorbin`.
    [#]# 1.3.1 - 2018-03-18
    [#]## Fixed
  - Distribute systemd preset template instead of the generated file.
    [#]# 1.3.0 - 2018-03-02
    [#]## Added
  - New configure option (--test-hwtpm) to run integration tests against a
    physical TPM2 device on the build platform.
  - Install systemd service file to allow on-demand systemd unit activation.
    [#]## Changed
  - Converted some inappropriate uses of g_error to critical / warning instead.
  - Removed use of gen_require from SELinux policy, use dbus_stub instead.
  - udev rules now give tss group read / write access to the TPM device node.
  - udev rules now give tss user and group read / write access to kernel RM
    node.
    [#]## Fixed
  - Memory leak on an error path in the AccessBroker.
* Thu Feb 22 2018 matthias.gerstner@suse.com
- update to upstream version 1.2.0:
  - Limit maximum number of active sessions per connection with '--max-sessions'.
  - Flush all transient objects and sessions on daemon start with '--flush-all'.
  - Allow passing of sessions across connections with ContextSave / Load.
  - Unref the GUnixFDList returned by GIO / dbus in the TCTI init function.
    This fixes a memory leak in the TCTI library.
- correctly trigger udev to update /dev/tpm* permissions after package
  installation. (bnc#1078687)
- prepared support_dbus_activation.diff patch which adds D-Bus activation, but
  can't use it yet due to rpmlint
* Wed Nov 15 2017 matthias.gerstner@suse.com
- fix_service_paths.diff: fixed broken systemd service unit (bnc#1066123). the
  service unit file in the upstream distribution tarball is already configured
  and looks for binaries and configuration files in the /usr/local prefix
  which is wrong.
* Fri Sep  1 2017 matthias.gerstner@suse.com
- package version symlink correctly, belongs into the lib package itself, not
  the -devel.
* Wed Aug 30 2017 matthias.gerstner@suse.com
- update to upstream version 1.1.1 which fixes some local denial-of-service
  security issues among other things:
  - Replace use of sigaction with g_unix_signal_* stuff from glib.
  - Rewrite of INSTALL.md including info on custom configure script options.
  - Default value for --with-simulatorbin configure option has been removed.
  New default behavior is to disable integration tests.
  - CommandSource will no longer reject commands without parameters.
  - Unit tests updated to use cmocka v1.0.0 API.
  - Integration tests now run daemon under valgrind memcheck and fail when
  errors are found.
  - CommandSource now tracks max FD in set of client FDs to prevent unnecessary
  iterations over FD_SETSIZE fds.
- no longer call bootstrap and switch to the release upstream tarball which
  has now been fixed to contain all necessary files
* Thu Jul 20 2017 matthias.gerstner@suse.com
- first version of the new arbmd resource manager from Intel's tpm2 stack.
  This will replace the old resourcemgr previously shipped with the
  tpm2-0-tss package.
